# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CompletionParams(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_success': 'bool',
        'error_info': 'str',
        'data': 'dict(str, object)'
    }

    attribute_map = {
        'is_success': 'is_success',
        'error_info': 'error_info',
        'data': 'data'
    }

    def __init__(self, is_success=None, error_info=None, data=None):  # noqa: E501
        """CompletionParams - a model defined in Swagger"""  # noqa: E501

        self._is_success = None
        self._error_info = None
        self._data = None
        self.discriminator = None

        self.is_success = is_success
        if error_info is not None:
            self.error_info = error_info
        if data is not None:
            self.data = data

    @property
    def is_success(self):
        """Gets the is_success of this CompletionParams.  # noqa: E501


        :return: The is_success of this CompletionParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_success

    @is_success.setter
    def is_success(self, is_success):
        """Sets the is_success of this CompletionParams.


        :param is_success: The is_success of this CompletionParams.  # noqa: E501
        :type: bool
        """
        if is_success is None:
            raise ValueError("Invalid value for `is_success`, must not be `None`")  # noqa: E501

        self._is_success = is_success

    @property
    def error_info(self):
        """Gets the error_info of this CompletionParams.  # noqa: E501


        :return: The error_info of this CompletionParams.  # noqa: E501
        :rtype: str
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """Sets the error_info of this CompletionParams.


        :param error_info: The error_info of this CompletionParams.  # noqa: E501
        :type: str
        """

        self._error_info = error_info

    @property
    def data(self):
        """Gets the data of this CompletionParams.  # noqa: E501

        additional data from the cluster  # noqa: E501

        :return: The data of this CompletionParams.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this CompletionParams.

        additional data from the cluster  # noqa: E501

        :param data: The data of this CompletionParams.  # noqa: E501
        :type: dict(str, object)
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompletionParams, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompletionParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
